package
module
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Feb 16, 2024
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
grpc-pingpong 
Generic "full-duplex" grpc based client/server.
Documentation
¶
type GrpcConfig struct {
LISTEN_NETWORK string
LISTEN_ADDRESS string
}
Runner functionality :
Init,Run and Stop grpc server
Prepares listener and creates grpc server
Starts grpc server, returns stop server function
for further usage during process finish
Source Files
¶
Directories
¶
internal
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Click to show internal directories.
Click to hide internal directories.